/**
 * Plugin to extract keywords and key-phrases.
 *
 * @type {import('unified').Plugin<[Options?]|[], Root>}
 */
export default function retextKeywords(
  options?: Options | undefined
):
  | void
  | import('unified').Transformer<import('nlcst').Root, import('nlcst').Root>
export type Root = import('nlcst').Root
export type Sentence = import('nlcst').Sentence
export type Word = import('nlcst').Word
export type SentenceContent = import('nlcst').SentenceContent
/**
 * Configuration.
 */
export type Options = {
  /**
   * Try to detect at most `maximum` `words` and `phrases`.
   *
   * Note that actual counts may differ.
   * For example, when two words have the same score, both will be returned.
   * Or when too few words exist, less will be returned. the same goes for
   * phrases.
   */
  maximum?: number | undefined
}
export type Keyphrase = {
  score: number
  weight: number
  stems: string[]
  value: string
  matches: PhraseMatch[]
}
export type Keyword = {
  matches: KeywordMatch[]
  score: number
  stem: string
}
export type PhraseMatch = {
  nodes: SentenceContent[]
  parent: Sentence
}
export type KeywordMatch = {
  node: Word
  index: number
  parent: Sentence
}
